diff --git a/src/wp-includes/general-template.php b/src/wp-includes/general-template.php
index 331d1f2..3fc2015 100644
--- a/src/wp-includes/general-template.php
+++ b/src/wp-includes/general-template.php
@@ -1471,14 +1471,16 @@ function single_month_title( $prefix = '', $display = true ) {
  * Display the archive title based on the queried object.
  *
  * @since 4.1.0
+ * @since 4.9.9 Added $span_class parameter.
  *
  * @see get_the_archive_title()
  *
  * @param string $before Optional. Content to prepend to the title. Default empty.
  * @param string $after  Optional. Content to append to the title. Default empty.
  */
-function the_archive_title( $before = '', $after = '' ) {
-	$title = get_the_archive_title();
+function the_archive_title( $before = '', $after = '', $span_class = '' ) {
+	$title = get_the_archive_title( $span_class );
 
 	if ( ! empty( $title ) ) {
 		echo $before . $title . $after;
@@ -1489,29 +1491,49 @@ function the_archive_title( $before = '', $after = '' ) {
  * Retrieve the archive title based on the queried object.
  *
  * @since 4.1.0
+ * @since 4.9.9 Added $span_class parameter.
  *
+ * @param string $span_class Optional. Class name to apply to the span around the archive type description. Default empty.
  * @return string Archive title.
  */
-function get_the_archive_title() {
+function get_the_archive_title( $span_class = '' ) {
 	if ( is_category() ) {
-		/* translators: Category archive title. %s: Category name */
-		$title = sprintf( __( 'Category: %s' ), single_cat_title( '', false ) );
+		/* translators: Category archive title. */
+		$type = __( 'Category:' );
+		$name = single_cat_title( '', false );
 	} elseif ( is_tag() ) {
-		/* translators: Tag archive title. %s: Tag name */
-		$title = sprintf( __( 'Tag: %s' ), single_tag_title( '', false ) );
+		/* translators: Tag archive title. */
+		$type = __( 'Tag:' );
+		$name = single_tag_title( '', false );
 	} elseif ( is_author() ) {
-		/* translators: Author archive title. %s: Author name */
-		$title = sprintf( __( 'Author: %s' ), '<span class="vcard">' . get_the_author() . '</span>' );
+		/* translators: Author archive title. */
+		$type = __( 'Author:' );
+		/* translators: %s: Author name. */
+		$name = sprintf( '<span class="vcard">%s</span>', get_the_author() );
 	} elseif ( is_year() ) {
-		/* translators: Yearly archive title. %s: Year */
-		$title = sprintf( __( 'Year: %s' ), get_the_date( _x( 'Y', 'yearly archives date format' ) ) );
+		/* translators: Yearly archive title. */
+		$type = __( 'Year:' );
+		$name = get_the_date( _x( 'Y', 'yearly archives date format' ) );
 	} elseif ( is_month() ) {
-		/* translators: Monthly archive title. %s: Month name and year */
-		$title = sprintf( __( 'Month: %s' ), get_the_date( _x( 'F Y', 'monthly archives date format' ) ) );
+		/* translators: Monthly archive title. */
+		$type = __( 'Month:' );
+		$name = get_the_date( _x( 'F Y', 'monthly archives date format' ) );
 	} elseif ( is_day() ) {
-		/* translators: Daily archive title. %s: Date */
-		$title = sprintf( __( 'Day: %s' ), get_the_date( _x( 'F j, Y', 'daily archives date format' ) ) );
-	} elseif ( is_tax( 'post_format' ) ) {
+		/* translators: Daily archive title. */
+		$type = __( 'Day:' );
+		$name = get_the_date( _x( 'F j, Y', 'daily archives date format' ) );
+	} elseif ( is_post_type_archive() ) {
+		/* translators: Post type archive title. */
+		$type = __( 'Archives:' );
+		$name = post_type_archive_title( '', false );
+	} elseif ( is_tax() ) {
+		$tax = get_taxonomy( get_queried_object()->taxonomy );
+		/* translators: Taxonomy singular name */
+		$type = sprintf( __( '%s:' ), $tax->labels->singular_name );
+		$name = single_term_title( '', false );
+	}
+	
+	if ( is_tax( 'post_format' ) ) {
 		if ( is_tax( 'post_format', 'post-format-aside' ) ) {
 			$title = _x( 'Asides', 'post format archive title' );
 		} elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
@@ -1531,13 +1553,13 @@ function get_the_archive_title() {
 		} elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
 			$title = _x( 'Chats', 'post format archive title' );
 		}
-	} elseif ( is_post_type_archive() ) {
-		/* translators: Post type archive title. %s: Post type name */
-		$title = sprintf( __( 'Archives: %s' ), post_type_archive_title( '', false ) );
-	} elseif ( is_tax() ) {
-		$tax = get_taxonomy( get_queried_object()->taxonomy );
-		/* translators: Taxonomy term archive title. 1: Taxonomy singular name, 2: Current taxonomy term */
-		$title = sprintf( __( '%1$s: %2$s' ), $tax->labels->singular_name, single_term_title( '', false ) );
+	} elseif ( isset( $type ) && isset( $name ) ) {
+		if ( ! empty( $span_class ) ) {
+			$span_class = sprintf( ' class="%s"', esc_attr( $span_class ) );
+			$title = sprintf( '<span%s>%s </span>%s', $span_class, $type, $name );
+		} else {
+			$title = sprintf( '%s %s', $type, $name );
+		}
 	} else {
 		$title = __( 'Archives' );
 	}
@@ -1546,10 +1568,12 @@ function get_the_archive_title() {
 	 * Filters the archive title.
 	 *
 	 * @since 4.1.0
+	 * @since 4.9.9 Added $span_class parameter.
 	 *
 	 * @param string $title Archive title to be displayed.
+	 * @param string $span_class Optional. Class name to apply to the span around the archive type description. Default empty.
 	 */
-	return apply_filters( 'get_the_archive_title', $title );
+	return apply_filters( 'get_the_archive_title', $title, $span_class );
 }
 
 /**
@@ -1471,14 +1471,16 @@ function single_month_title( $prefix = '', $display = true ) {
  * @see get_the_archive_title()
  *
- * @param string $before Optional. Content to prepend to the title. Default empty.
- * @param string $after  Optional. Content to append to the title. Default empty.
+ * @param string $before     Optional. Content to prepend to the title. Default empty.
+ * @param string $after      Optional. Content to append to the title. Default empty.
+ * @param string $span_class Optional. Class name to apply to the span around the archive type description. Default empty.
  */
